@@ -34,7 +34,9 @@ pub struct InputObjectTypeDef {
 impl From<InputObjectTypeDef> for apollo_encoder::InputObjectDefinition {
     fn from(input_object_def: InputObjectTypeDef) -> Self {
         let mut new_input_object_def = Self::new(input_object_def.name.into());
-        new_input_object_def.description(input_object_def.description.map(String::from));
+        if let Some(description) = input_object_def.description {
+            new_input_object_def.description(description.into());
+        }
         if input_object_def.extend {
             new_input_object_def.extend();
         }
